__author__ = 'faide'

import unittest

from nose.tools import raises

from py3o.formats import UnkownFormatException
from py3o.formats import Formats
from py3o.formats import Format
from py3o.formats import FORMAT_PDF


class TestFormats(unittest.TestCase):

    def tearDown(self):
        pass

    def setUp(self):
        self.formats = Formats()

    def test_valid_format(self):
        """test that a valid format can be found"""
        res = self.formats.get_format(FORMAT_PDF)
        assert isinstance(res, Format)

        assert res.name == "pdf"
        assert res.odfname == "writer_pdf_Export"
        assert res.mimetype == "application/pdf"

    @raises(UnkownFormatException)
    def test_invalid(self):
        self.formats.get_format('invalidformat')

    def test_get_format_names(self):
        names = self.formats.get_known_format_names()
        assert FORMAT_PDF in names



from py3o.formats.main import UnkownFormatException
from py3o.formats.main import Formats
from py3o.formats.main import Format
from py3o.formats.main import FORMAT_DOCBOOK
from py3o.formats.main import FORMAT_HTML
from py3o.formats.main import FORMAT_ODT
from py3o.formats.main import FORMAT_PDF
from py3o.formats.main import FORMAT_WORD2003
from py3o.formats.main import FORMAT_WORD97



# -*- coding: utf-8 -*-

DEFAULT_MIMETYPE = "application/octet-stream"

FORMAT_WORD97 = "doc"
FORMAT_WORD2003 = "docx"
FORMAT_PDF = "pdf"
FORMAT_DOCBOOK = "docbook"
FORMAT_HTML = "html"
FORMAT_ODT = "odt"
FORMAT_ODS = "ods"
FORMAT_XLS = "xls"


class UnkownFormatException(Exception):
    pass


class Format(object):

    def __init__(self, name, odfname, mimetype=DEFAULT_MIMETYPE, native=False):
        self.name = name
        self.odfname = odfname
        self.mimetype = mimetype
        self.native = native


class Formats(object):

    def __init__(self):

        self._formats = {
            FORMAT_WORD97: Format(
                FORMAT_WORD97, "MS Word 97", "application/msword"
            ),
            FORMAT_WORD2003: Format(
                FORMAT_WORD2003, "MS Word 2003 XML",
                "application/vnd.openxmlformats-officedocument"
                ".wordprocessingml.document"
            ),
            FORMAT_PDF: Format(
                FORMAT_PDF, "writer_pdf_Export", "application/pdf"
            ),
            FORMAT_DOCBOOK: Format(
                FORMAT_DOCBOOK, "DocBook File", "application/xml"
            ),
            FORMAT_HTML: Format(FORMAT_HTML, "HTML", "text/html"),
            FORMAT_ODT: Format(
                FORMAT_ODT, "writer8",
                "application/vnd.oasis.opendocument.text",
                native=True,
            ),
            FORMAT_ODS: Format(
                FORMAT_ODS, "calc8",
                "application/vnd.oasis.opendocument.spreadsheet",
                native=True,
            ),
            FORMAT_XLS: Format(
                FORMAT_XLS, "MS Excel 97", "application/msexcel"
            ),
        }

    def get_format(self, name):
        f = self._formats.get(name)

        if not f:
            raise UnkownFormatException("Format {} is unkown".format(name))

        return f

    def get_known_format_names(self, nativeonly=False):
        """return the a list of names that can be used as format names in
        py3o.template.

        :param nativeonly: a boolean flag. If set to True will only return
        native formats.
        :type nativeonly: bool

        :return: list of chars
        :returntype: list

        :raises: nothing
        """
        if nativeonly:
            return [
                f for f in self._formats if self.get_format(f).native
            ]
        else:
            return [f for f in self._formats]



# -*- coding: utf-8 -*-
from setuptools import setup, find_packages

version = '0.3'

setup(
    name='py3o.formats',
    version=version,
    description="Formats declarations for py3o",
    long_description=open("README.rst").read(),
    classifiers=[
        "Programming Language :: Python",
        "Topic :: Internet :: WWW/HTTP :: HTTP Servers",
        "Topic :: Text Processing :: General",
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    keywords='py3o',
    author='Björn Ricks',
    author_email='bjoern.ricks@gmail.com',
    url='http://bitbucket.org/faide/py3o.formats',
    license='MIT License',
    packages=find_packages(exclude=['ez_setup', 'examples', 'tests']),
    namespace_packages=['py3o'],
    include_package_data=True,
    zip_safe=True,
    install_requires=[
        'setuptools',
    ],
    tests_require=['nose', 'nosexcover'],
    test_suite='nose.collector',
)
